Learn R Programming

evobiR (version 1.0)

GetTaxonomy: Create a taxonomy table

Description

This function is an extension of the tax_name function from the package taxize. The input is a tree and the function will return a table with a description of the taxonomy of all species on the tree

Usage

GetTaxonomy(tree, database = "ncbi")

Arguments

tree
an object of class "phylo"
database
character string "ncbi or "itis" indicating the database that should be used

Value

  • this function saves a csv file named: tree.taxonomy.csv

References

http://www.uta.edu/karyodb/evobiR/

Examples

Run this code
# data(hym.tree)
# GetTaxonomy(tree = hym.tree, database = 'ncbi')

Run the code above in your browser using DataLab