Learn R Programming

evobiR (version 1.0)

evobiR-package: evobiR: Evolutionary Biology in R

Description

evobiR is a collection of tools for use in evolutionary biology. Some of the functions manipulate data in a way not implemented by other functions while others calculate sequence statistics or perform simulations, either of data across trees or genetic and genomic simulations.

Arguments

Details

ll{ Package: evobiR Type: Package Version: 1.0 Date: 2013-10-08 License: GPL (>=2) } More information on evobiR is available at http://www.uta.edu/karyodb/evobiR/

A full list of functions in the evobiR package is accesible by typing library(help = evobiR)