Learn R Programming

evobiR (version 1.0)

genome: A small portion of the genome of Tribolium confusum

Description

This is just little piece of the Tribolium confusum genome

Arguments

format

a list of vectors with each element being a single string of the class "SeqFastadna".

References

http://www.uta.edu/karyodb/evobiR/