Learn R Programming

evobiR (version 1.0)

mcmc2: mcmc log file

Description

A 5 column by 100 row double matrix from a mcmc log file. The first column is the tree used during the iteration the remaining columns are the rate parameters of the Q matrix listed by column order.

Arguments