Learn R Programming

evobiR (version 1.0)

taxa.table: A table with taxonomic information

Description

This character matrix contains species in one column followed by the genera and the family membership of each species

Arguments