This function simulates the coalescence of linages through time. At the begining of the simulation a number of unique lineages specified by the census size as we go back in time these coalesce until we have only a single lineage remaining.
Usage
CoalSim(census, lw, ln.col)
Arguments
census
the size of population to use in the simulation.
lw
line width factor passed to the plotting function.
ln.col
specifies the color to be used in plotting the coalesence history
Value
Returns a plot showing the result of the coalescence simulation.